
llstatus - Query machine status

Purpose

Returns status information about machines in the  LoadLeveler
cluster. It does not provide status on any NQS machine.

Syntax

llstatus [-?] [-H] [-v] [-R] [-F] [-M] [-l] [-a] [-C] [-b]
         [-B {base_partition_list | all}] [-P {partition_list | all}]
         [-X {cluster_list | all}] [-f category_list] [-r category_list]
         [-h hostlist | hostlist]

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level, 
   service level date, and lowest level of the operating system to 
   run this release.

-R 
   Lists the machine consumable resources associated with each 
   machine for which status is requested. This option should not
   be used with any other option.

-F 
   Lists all of the floating consumable resources associated with the 
   LoadLeveler cluster. This option should not be used with any other 
   option.

-M 
   Lists the Multiple Chip Modules (MCMs) available on a machine, where: 

   Available CPUs
	  Are the CPU IDs of the CPUs available for LoadLeveler
	  on this MCM.
   Used CPUs
	  Are the CPU IDs of the CPUs used by LoadLeveler jobs
	  on this MCM.
   Adapters 
          Are the switch adapters connected to this MCM of the form: 

	  [used windows/available windows, used memory/available memory]	   

	  where:	   

	  used windows
		   Is the total number of windows used.

	  available windows
		   Is the total number of available windows.

	  used adapter window memory
		   For High Performance Switch adapters, it is
		   the number of rCxt blocks used. 

		   For information on the units used to report
		   window memory, see the description of the
		   "Adapter" field in the long listing.

	  available adapter window memory
		   For High Performance Switch adapters, it is
		   the number of rCxt blocks used. 

		   For information on the units used to report
		   window memory, see the description of the
		   "Adapter" field in the long listing.

   Total Tasks
	  Is the total number of tasks that are running using
	  CPUs of this MCM.  

   Note that the < > notation will be used to list individual CPU IDs  
   instead of the CPU count ( ) notation when the RSET_SUPPORT  
   configuration file keyword is set to RSET_CONSUMABLE_CPUS or 
   RSET_MCM_AFFINITY.

-l 
   Specifies that a long listing be generated for each machine for
   which status is requested. If -l is not specified, the standard
   list is generated.

-a 
   Displays information for each virtual adapter followed by
   information for each physical adapter it manages.

-C 
   Displays cluster stanza information defined in the administration 
   file.  Only fields that contain data are displayed.  If -C is 
   specified without the -X flag, cluster stanza information will be 
   reported from one outbound local schedd.  If the -X and -C flags 
   are specified, cluster stanza information will be reported from  
   an inbound schedd in each available remote cluster specified with 
   the -X flag. If the -h flag is specified, cluster stanza information 
   will only be reported from the specified hosts.

-b 
   Displays Blue Gene system information. It is valid only when
   specified as a single option or in combination with the -l flag. 
   When used as single option, llstatus displays a short listing of 
   information on the Blue Gene system. When used the -l flag, llstatus 
   displays a detailed listing of the components of the Blue Gene 
   system.

-P {partition_list | all}
   Displays Blue Gene partition information. It is valid only when
   specified as a single option. When this flag is specified,
   llstatus displays information on all Blue Gene partitions in
   the partition_list. 

   partition_list    Is a blank-delimited list of Blue Gene partitions.

   all               Is the reserved word indicating that the command 
                     is to return information for all partitions.

-B {base_partition_list | all}
   Displays Blue Gene base partition information. It is valid only
   when specified as a single option. When this flag is specified,
   llstatus displays information on all Blue Gene base partitions
   in the base_partition_list. 

   base_partition_list
		     Is a blank-delimited list of Blue Gene base 
		     partitions.

   all               Is the reserved word indicating that the command is 
                     to return information for all base partitions.

-X {cluster_list | all}
   Indicates that you can specify the -X flag with either:  

   cluster_list      Specifies a blank-delimited list of clusters for 
                     which status is requested.

   all               Is a reserved word which specifies that status is 
                     requested for all accessible clusters.

-f category_list
   Is a blank-delimited list of categories you want to query. Each
   category you specify must be preceded by a percent sign. The
   category_list cannot contain duplicate entries. This flag
   allows you to create a customized version of the standard
   llstatus listing. The output fields produced by this flag all
   have a fixed length. The output is displayed in the order in
   which you specify the categories. category_list can be one or
   more of the following:

   %a       Hardware architecture

   %act     Number of job steps dispatched by the schedd daemon on
	    this machine

   %cm      Custom Metric value

   %cpu     Number of CPUs on this machine

   %d       Available disk space in the  LoadLeveler execute directory

   %i       Number of seconds since last keyboard or mouse activity

   %inq     Number of job steps in the job queue of this schedd machine

   %l       Berkeley one-minute load average

   %m       Physical memory on this machine

   %mt      Maximum number of initiators that can be used
	    simultaneously on this machine

   %n       Machine name

   %o       Operating system on this machine

   %r       Number of initiators used by the startd daemon on this 
            machine

   %sca     Availability of the schedd daemon

   %scs     State of the schedd daemon

   %sta     Availability of the startd daemon

   %sts     State of the startd daemon

   %v       Available swap space (free paging space) of this machine

   %X       Local cluster name

-r category_list
   Is a blank-delimited list of categories you want to query. Each
   category you specify must be preceded by a percent sign. The
   category_list cannot contain duplicate entries. This flag
   allows you to create a customized version of the standard
   llstatus listing. The output produced by this flag is
   considered raw, in that the fields can be variable in length.
   The output is displayed in the order in which you specify the
   formats. Output fields are separated by an exclamation point (!). 
   category_list can be one or more of the categories listed under 
   the -f flag.

-h hostlist
   Is a blank-delimited list of machines for which status is requested. 

   If the -X flag is specified in combination with a hostlist, the
   -h flag must be specified.  For example:  

   llstatus -X my_cluster1 my_cluster2 -h c94n13 c94n14

Description

If you have more than a few machines configured for LoadLeveler,
consider redirecting the output to a file when using the -l flag.

Each machine periodically updates the central manager with a snapshot 
of its situation. Since the information returned by using llstatus is 
a collection of such snapshots, all taken at varying times, the total 
picture may not be completely consistent.

In most cases, if a hostlist is not specified, all machines are
queried. However, if the -X and -C flags are specified without a
hostlist, the command will run on one inbound schedd in the
remote cluster.

Certain resources such as remote direct-memory access (RDMA) have
their available value always calculated by startd. Available
ConsumableCpus resources are calculated by startd if the value  is
specified as all in the administration file. When the value of a
resource is calculated by startd, the llstatus command appends a
plus (+) sign to the resource name in the output reports.
Resources that are automatically created, such as RDMA, have a 
less than (<) sign appended to them.

Examples

1. This example generates the standard listing where there are two
   nodes in the cluster. The standard listing is generated when
   you do not specify the -l option with the llstatus command.  

   llstatus   

   You should receive output similar to the following:
 
   Name                   Schedd InQ Act Startd Run LdAvg Idle Arch  OpSys
   k10n09.ppd.pok.ibm.com Avail   3   1  Run      1 2.72     0 R6000 AIX53
   k10n12.ppd.pok.ibm.com Avail   0   0  Idle     0 0.00   365 R6000 AIX53
 
   R6000/AIX53            2 machines   3 jobs   1 running
   Total Machines         2 machines   3 jobs   1 running
  
   The Central Manager is defined on k10n09.ppd.pok.ibm.com
 
   The BACKFILL scheduler is in use
 
   Cluster name is cluster2
 
   All machines on the machine_list are present.   

   The standard listing includes the following fields:  

   Act      Number of job steps dispatched by the schedd daemon on this 
            machine.

   Arch     The hardware architecture of the machine as listed in
	    the configuration file.

   Idle     The number of seconds since keyboard or mouse activity
	    in a login session was detected. Highest number
	    displayed is 9999.

   InQ      Number of job steps in the job queue of this schedd machine.

   LdAvg    Berkeley one-minute load average on this machine.

   Name     Hostname of the machine.

   OpSys    The operating system on this machine.

   Run      The number of initiators used by the startd daemon to
	    run  LoadLeveler jobs on this machine. One initiator
	    is used for each serial job step and one initiator is
	    used for each task of a parallel job step.

   Schedd   State of the schedd daemon, which can be one of the
	    following: 
	    *  Down
	    *  Drned (Drained)
	    *  Drning (Draining)
	    *  Avail (Available)	   

	    For more information, see the description of the
	    schedd daemon in LoadLeveler: Using and Administering.

   Startd   State of the startd daemon, which can be: 
	    *  Busy
	    *  Down
	    *  Drned (Drained)
	    *  Drning (Draining)
	    *  Flush
	    *  Idle
	    *  None
	    *  Run (Running)
	    *  Suspnd (Suspend)	   

	    For more information, see the description of the
	    startd daemon in LoadLeveler: Using and Administering.

   Total Machines
	    The standard listing includes the following summary fields: 

	    jobs     The number of job steps in LoadLeveler job queues.

	    machines 
	             The number of machines in the cluster that have 
		     made a status report to the Central Manager.

	    running  The number of initiators used by all the startd 
	             daemons in the LoadLeveler cluster. One initiator 
		     is used for each serial job step. One initiator is 
		     used for each task of a parallel job step.  

   The standard listing also contains summary information for the
   cluster such as the type of scheduler and the cluster name.

2. This example generates the long listing. The long listing is
   generated when you specify the -l flag with the llstatus
   command.  See "Appendix B. Sample command output" for sample
   output of long listings in LoadLeveler: Using and Administering. 

   llstatus -l c271f2rp02  

   The long listing includes the following fields:  

   Adapter  Network adapter information associated with this
 	    machine. 

	    *  For a switch adapter, the information format is:  

	       adapter_name(network_type, interface_name,
	       interface_address,  multilink_address,
	       switch_node_number or adapter_logical_id,
	       available_adapter_windows/total_adapter_windows, 
	       available_device_memory/total_device_memory,
	       adapter_fabric_connectivity, adapter_state)	      

	       For example:	      

	       Adapter = networks(striped,c60f1rp01ml0.ppd.pok.ibm.com, \  
	       10.10.10.1,,-1,32/32,1596/1596 rCxt Blks,1,READY) \ 
	       en0(ethernet,c60f1rp01.ppd.pok.ibm.com,9.114.88.65,) \
	       network1(aggregate,,,10.10.10.1,-1,32/32,1596/1596 \
	       rCxt Blks,1,READY)ml0(multilink,c60f1rp01ml0.ppd.pok. \
	       ibm.com,10.10.10.1,)	      

	       Note: The available_device_memory and
		     total_device_memory fields (also referred to
		     as available window memory and total window
		     memory) may be reported in megabytes (as
		     indicated by M in the previous example) or
		     rCxt blocks, depending on the type of switch
		     adapter that is present.   

		     The following adapters report adapter window memory 
		     in MBs:
		    
		     *  SP Switch2 Adapter
		     *  SP Switch2 PCI Attachment Adapter
		     *  SP Switch2 MX2 Adapter
		     *  SP Switch2 PCI-X Attachment Adapter		    

		     The following adapter reports adapter window
		     memory in rCxt Blocks:
		    
		     *  Switch Network Interface for the High
		        Performance Switch	      

	       Possible values for adapter_state are:	      

	       READY    The adapter can be used for communication.

	       NOT_READY
		     The adapter is not ready to be used for 
		     communication.

	       -1    The state of the adapter cannot be determined 
	             because the machine that it is on cannot be 
		     contacted.

	    *  For non-switch adapters, the format is:  

	       adapter_name(network_type, interface_name,
	       interface_address, multilink_address)

   Arch     Hardware architecture of this machine.

   AvailableClasses
	    List of available classes and the associated number of
	    available initiators on this machine.

   Completed
	    The number of job steps in this state on this schedd 
	    machine.

   Config Time Stamp
	    Date and time of last configuration or reconfiguration.

   ConfiguredClasses
	    List of configured classes and the associated number
	    of configured initiators on this machine.

   ConsumableResources
	    List of consumable resources associated with this
	    machine. Each element of this list has the format:
	    resource_name(available, total). 

	    Note: The individual CPU ID < > notation will be used
		  to list individual  CPU IDs instead of the CPU
		  count ( ) notation for machines where the
		  RSET_SUPPORT configuration file keyword is set
		  to RSET_MCM_AFFINITY or  RSET_CONSUMABLE_CPUS. 
		  The CPU count ( ) notation will be used when the
		  RSET_SUPPORT configuration file keyword is set
		  to RSET_USER_DEFINED or RSET_NONE, or if this
		  keyword is not specified in the configuration
		  file.

   CONTINUE 
            The expression, defined following C conventions in the
	    configuration file, that evaluates to true or false (T
	    or F). This determines whether suspended jobs are
	    continued on this machine.

   Cpus     Number of CPUs on this machine.

   CustomMetric
	    This value can be the number assigned to the
	    CUSTOM_METRIC keyword or the exit code of the
	    executable associated with the CUSTOM_METRIC_COMMAND
	    keyword or the default value of 1.

   Disk     Available space, in kilobytes (less 512KB) in
	    LoadLeveler's execute directory on this machine.

   DrainedClasses
	    List of classes which have been drained. If a job step
	    is in a class named on this list, that job step will
	    not start on this machine.

   DrainingClasses
	    List of classes which are currently being drained on this 
	    machine. If a job step is in a class named on this list, 
	    that job step will not start on this machine.

   Entered Current State
	    Date and time when machine state was set.
  
   FabricConnectivity
	    Represents the current state of connectivity between
	    the machine and the switch through the switch
	    adapters. The format of the field is:  network_id:
	    connectivity, network_id: connectivity... where
	    connectivity is either 1 or 0. A value of 1 indicates
	    an active connection from the machine to a given
	    network_id through one of the switch adapters. 

	    If a machine does not have switch adapters, the
	    FabricConnectivity field has no meaning and should be
	    ignored by the user.

   Feature  Set of all features on this machine.

   FreeLargePageMemory
	    Free Large Page memory.

	    In LoadLeveler for Linux, the FreeLargePageMemory field has 
	    no meaning and should be ignored by the user.

   FreeRealMemory
	    Free real memory, in megabytes, on this machine. This
	    value should track closely with the "fre" value of the
	    vmstat command and the "free" value of the svmon -G
	    command whose units are 4KB blocks.

   Held     The number of job steps in this state on this schedd
	    machine.

   Idle     The number of job steps in this state on this schedd
	    machine.

   Keyboard Idle
	    Number of seconds since last keyboard or mouse activity.

   KILL     The expression, defined following C conventions in the
	    configuration file, that evaluates to true or false (T
	    or F). This determines whether jobs running on this
	    machine should be sent the SIGKILL signal.

   LargePageMemory
	    Configured Large Page physical memory.

	    In LoadLeveler for Linux, the LargePageMemory field
	    has no meaning and should be ignored by the user.


   LargePageSize
	    The size of a Large Page memory block. 

	    In LoadLeveler for Linux, the LargePageSize field has
	    no meaning and should be ignored by the user.

   LoadAvg  Berkely one-minute load average on machine.

   Machine  Fully qualified name of the machine.

   Machine Mode
	    The type of job this machine can run. This can be: 
	    batch, interactive, or general.

   MACHPRIO 
            Actual expression that determines machine priority,
	    defined in the configuration file.

   MasterMachPriority
	    The machine priority for the parallel master node.

   Max_Starters
	    Maximum number of initiators that can be used
	    simultaneously on this machine.

   Mcms     The MCMs information associated with this machine has
	    the format: 

	    mcm_info ... mcm_info
  
	    The format of mcm_info is:	    

	    MCMnumber Available Cpus: < cpulist > (Total Cpus)  
	    Used Cpus: < cpulist > (Total Cpus)  
	    Adapters: adapater_info .... adapter_info 
	    Total Tasks: (Tasks) 	   

	    where:	   

	    Available Cpus
		     Are the CPUs available for LoadLeveler on
		     this MCM.

	    Used Cpus
		     Are the CPUs used by LoadLeveler jobs from this 
		     MCM.

	    Adapters Are the switch adapters connected to this MCM.

	    Total tasks
		     Is the total number of tasks that are running
		     using CPUs of this MCM. 

		     where number is the MCM sequence number:		    

		     cpulist  Is a blank-delimited list of individual 
		              CPU IDs or CPU ranges, or a combination 
			      of both CPU IDs and CPU ranges
		              associated  with the MCM.

		     adapter_info
		              Has the format:   

		              [used windows/available windows, used
		              memory/available memory]		    

		     where:		    

		     used windows
		       Is the total number of windows used.

		     available windows
		       Is the total number of available windows.

		     used memory
		       Is the total memory used.  It is the number
		       of rCxt blocks for the High Performance
		       Switch adapter.

		     available memory
		       Is the total available memory.  It is the
		       number of rCxt blocks for the High
		       Performance Switch adapter.

		     Tasks    
		       Is the total number of tasks that are
		       running using  the CPUs of this MCM.

   Memory   Regular physical memory, in megabytes, on this machine.

   Name     Hostname of the machine.

   OpSys    Operating system on this machine.

   PagesFreed
	    Pages freed per second. This value corresponds to the
	    "fr" value of the vmstat command output. 

	    In LoadLeveler for Linux, the PagesFreed field has no
	    meaning and should be ignored by the user.

   PagesPaged In
	    Pages paged in from paging space per second. This value 
	    corresponds to the "pi" value of the vmstat command output. 

	    In LoadLeveler for Linux, the PagesPagedIn field has
	    no meaning and should be ignored by the user.

   PagesPagedOut
	    Pages paged out to paging space per second. This value
	    corresponds to the "po" value of the vmstat command output. 

	    In LoadLeveler for Linux, the PagesPagedOut field has
	    no meaning and should be ignored by the user.
  
   PagesScanned
	    Pages scanned by the page-replacement algorithm per
	    second. This value corresponds to the "sr" value of
	    the vmstat command output. 

	    In LoadLeveler for Linux, the PagesScanned field has
	    no meaning and should be ignored by the user.

   Pending  The number of job steps in this state on this schedd 
            machine.

   Pool     The identifier of the pool where this startd machine
	    is located.

   Prestarted_Starters
	    The maximum number of Prestarted Starters that can
	    be started on this machine at any time.

   Remove Pending
	    The number of job steps in this state on this schedd
	    machine.

   ReservationPermitted
	    Indicates whether or not the node can be reserved. It
	    is displayed as T or F (true or false).

   Reservations
	    The IDs of reservations that will use the node now or
	    in the future.

   RSetSupportType
	    Indicates the type of RSet support set up on a
	    machine.  Possible values are: 

	    RSET_CONSUMABLE_CPUS
		     Creates and attaches RSets for tasks with the
		     number of CPUs derived from ConsumableCPUs.
	    RSET_MCM_AFFINITY
		     Creates and attaches RSets for tasks to
		     satisfy memory and affinity requests.
	    RSET_NONE
		     Indicates that LoadLeveler RSet support is
		     not available.
	    RSET_USER_DEFINED
		     Attaches user-created RSets to Tasks.

   Running  The number of initiators used by the startd daemon to
	    run  LoadLeveler jobs. One initiator is used for each
	    serial job step. One initiator is used for each task
	    of a parallel job step.

   Running steps
	    The list of job steps currently running on this machine.

   ScheddAvail
	    Flag indicating if machine is running a schedd daemon
	    (0=no, 1=yes).

   ScheddRunning
	    The number of job steps submitted to this machine that
	    are running somewhere in the LoadLeveler cluster.

   ScheddState
	    The state of the schedd daemon on this machine, which
	    can be one of the following: 
	    *  Down
	    *  Drned (Drained)
	    *  Drning (Draining)
	    *  Avail (Available)

   Speed    Speed associated with the machine.

   START    The expression, defined following C conventions in the
  	    configuration file, that evaluates to true or false (T
	    or F). This determines whether jobs can be started on
	    this machine.

   StartdAvail
	    Flag indicating if machine is running a startd daemon
	    (0=no, 1=yes).

   Starting 
            The number of job steps in this state on this schedd
	    machine.

   State    State of the startd daemon, which can be:
	    *  Busy
	    *  Down
	    *  Drained
	    *  Draining
	    *  Flush
	    *  Idle
	    *  None
	    *  Running
	    *  Suspend	   

	    For more information, see the description of the
	    startd daemon in LoadLeveler: Using and Administering.

   Subnet   The TCP/IP subnet that this machine resides on.

   SUSPEND  The expression, defined following C conventions in the
	    configuration file, that evaluates to true or false (T
	    or F). This determines whether running jobs should be
	    suspended on this machine.

   SYSPRIO  Actual expression that determines overall system priority 
            of a job step. Defined in the configuration file.

   TimeStamp
	    The date and time the central manager last received a
	    status update from this schedd machine.

   Tmp      Available space, in kilobytes (less than 512 KB) in
	    the /tmp directory on this machine.

   Total Jobs
	    The number of total job steps submitted to this schedd
	    machine.

   TotalMemory
	    The sum of configured regular and Large Page memory.

   Unexpanded
	    The number of job steps in this state on this schedd
	    machine.

   VACATE   The expression, defined following C conventions in the
	    configuration file, that evaluates to true or false (T
	    or F). This determines whether suspended jobs are
	    vacated on this machine.

   Virtual Memory
	    Available swap space (free paging space) in kilobytes,
	    on this machine.

3. This example generates a listing of cluster information 
   defined in the administration file for cluster2. Only fields
   with data are displayed. 

   llstatus -X cluster2 -C  

   The output representing a cluster is delineated with a cluster
   header similar to the following:  

   =================== Cluster cluster2 ================================
 
   llstatus: Sending request to Schedd "c188f2n08.ppd.pok.ibm.com" in 
  	     cluster "cluster2"
 
   cluster2: type = cluster
	   Local = True
	   inbound_schedd_port = 9605
	   secure_schedd_port = 9607
	   multicluster_security = NOT_SET
	   ssl_cipher_list = ALL:eNULL:!aNULL
	   inbound_hosts = c188f2n08.ppd.pok.ibm.com
	   outbound_hosts = c188f2n08.ppd.pok.ibm.com
	   exclude_classes = badtesters(cluster3) OKtesters(cluster1)
 
   cluster1: type = cluster
	   Local = False
	   inbound_schedd_port = 9605
	   secure_schedd_port = 9607
	   multicluster_security = NOT_SET
	   ssl_cipher_list = ALL:eNULL:!aNULL
	   inbound_hosts = c188f2n02.ppd.pok.ibm.com
	   outbound_hosts = c188f2n02.ppd.pok.ibm.com
	   exclude_users = loadl(cluster2)
	   exclude_groups = april(cluster3)
	   include_classes = No_Class
 
   cluster3: type = cluster
	   Local = False
	   inbound_schedd_port = 1966
	   secure_schedd_port = 9607
	   multicluster_security = NOT_SET
	   ssl_cipher_list = ALL:eNULL:!aNULL
	   inbound_hosts = c94n02.ppd.pok.ibm.com
	   outbound_hosts = c94n02.ppd.pok.ibm.com(cluster1) 
			    c94n06.ppd.pok.ibm.com(cluster2) 
 
4. This example generates a listing of all of the consumable resources 
   associated with all of the machines in the LoadLeveler cluster.  

   llstatus -R

   You should receive output similar to the following:

   Machine                     Consumable Resource(Available, Total)
   -------------------------   -------------------------------------
   c209f1n01.ppd.pok.ibm.com   ConsumableCpus(4,4)+ ConsumableMemory \
				(1.000 gb,1.000 gb) n01_res(123,500)
   c209f1n02.ppd.pok.ibm.com   ConsumableCpus< 0 1 2 3 4>< 0 1 2 3 4 > \ 
				n02_res(123,500) Frame5(10,10)
   c209f1n05.ppd.pok.ibm.com   ConsumableCpus(4,4)+ ConsumableMemory \
				(1.000 gb,1.000 gb) spice2g6(250,360)
 
   Resources with "+" appended to their names have the Total value 
   reported from Startd.  

   Note: The individual CPU ID < > notation will be used to list
         individual CPU IDs instead of the CPU count ( ) notation
         for machines where the RSET_SUPPORT configuration file
         keyword is set to RSET_MCM_AFFINITY or 
         RSET_CONSUMABLE_CPUS.  The CPU count ( ) notation will be
         used when the RSET_SUPPORT configuration file keyword is
         set to RSET_USER_DEFINED or RSET_NONE, or if this
         keyword is not specified in the configuration file.

5. This example generates a listing of information related to MCMs
   of machines in the LoadLeveler cluster. 
    
   llstatus -M   

   You should receive output similar to the following:
 
   Machine               MCM details 
   --------------------- -------------------------------------------------
   c61f2sq01.ppd.pok.ibm.com
	        MCM0
	  	   Available Cpus :< 0-15 >(16)
		   Used Cpus      :< >(0)
		   Adapters       :
		   Total Tasks    :(0)
	        MCM1
		   Available Cpus :< 16-29 >(14)
		   Used Cpus      :< 16-27 >(12)
		   Adapters       :sn1[16/16,798/798 rCxt Blks]
				   sn0[12/16,790/798 rCxt Blks]
		   Total Tasks    :(4)
	     
   c61f2sq02.ppd.pok.ibm.com
	        MCM0
		   Available Cpus :< 0-1 >(2)
		   Used Cpus      :< >(0)
		   Adapters       :
		   Total Tasks    :(0)
	        MCM1
		   Available Cpus :< 2-3 >(2)
		   Used Cpus      :< >(0)
		   Adapters       :
		   Total Tasks    :(0) 

   Note: The -M option will list the MCM information only when the
	 RSET_SUPPORT  configuration file keyword is set to
         RSET_MCM_AFFINITY.

6. This example generates a listing of all of the floating consumable 
   resources associated with all of the machines in the LoadLeveler 
   cluster. This option should not be specified with any other option.  

   llstatus -F  

   You should receive output similar to the following:
 
   Floating Resource              Available     Total          
   ------------------------------ ------------- ---------------
   EDA_licenses                   20            29           
   Frame5                         15            20           
   WorkBench6                     5             7            
   XYZ_software                   6             6            
 
7. This example generates a customized and formatted standard listing.    
 
   llstatus -f %n %scs %inq %m %v %sts %l %o 

   You should receive output similar to the following:
 
   Name             Schedd  InQ  Memory FreeVMemory Startd  LdAvg  OpSys
   ll5.pok.ibm.com  Avail   0    128    22708       Run     0.23   AIX53
   ll6.pok.ibm.com  Avail   3    224    16732       Run     0.51   AIX53
 
   R6000/AIX53                 2 machines      3  jobs      3  running
   Total Machines              2 machines      3  jobs      3  running
 
   The Central Manager is defined on ll5.pok.ibm.com
 
   The BACKFILL scheduler is in use
 
   All machines on the machine_list are present. 

8. This example generates a customized and unformatted (raw)
   standard listing. 

   Customized, Unformatted Standard Listing: A customized Output
   fields are separated by an exclamation point (!).  

   llstatus -r %n %scs %inq %m %v %sts %l %o  

   You should receive output similar to the following:  

   ll5.pok.ibm.com!Avail!0!128!22688!Running!0.14!AIX53
   ll6.pok.ibm.com!Avail!3!224!16668!Running!0.37!AIX53

9. This example generates a listing containing information about
   the status of adapters associated with all of the machines in
   the LoadLeveler cluster:  

   llstatus -a  

   You should receive output similar to the following:  

   c271f2rp02.ppd.pok.ibm.com
   ml0(multilink,c271f2san02.ppd.pok.ibm.com,10.10.10.6,)
   networks(striped,c271f2san02.ppd.pok.ibm.com,10.10.10.6,,-1, \
            500/512,500M/512M,1,READY)
   network1(aggregate,,,10.10.10.6,-1,500/512,500M/512M,1,READY)
     sn0(switch,c271f2s0n02.ppd.pok.ibm.com,192.168.0.6,10.10.10.6,2, \
         250/256,250M/256M,1,READY,MCM0)
     sn1(switch,c271f2s1n02.ppd.pok.ibm.com,192.168.1.6,10.10.10.6,0, \
         250/256,250M/256M,1,READY,MCM0)
   en0(ethernet,c271f2rp02.ppd.pok.ibm.com,9.114.175.82,)
  
   *  For a switch adapter, the information format is:  

      adapter_name(network_type, interface_name,
      interface_address, multilink_address,  switch_node_number or
      adapter_logical_id,
      available_adapter_windows/total_adapter_windows, 
      available_device_memory/total_device_memory,
      adapter_fabric_connectivity, adapter_state[,adapter mcm id])

   *  For non-switch adapters, the format is:  

      adapter_name(network_type, interface_name,
      interface_address, multilink_address)  

   Note: The adapter MCM ID will be printed only for High
         Performance Switch adapters and only when the
         RSET_SUPPORT configuration file keyword is set to
         RSET_MCM_AFFINITY.  A value of MCM-1 for this field means
         that none of the CPUs from the physical MCM, where that
         adapter is connected to, is part of the machine's partition.

10. This example generates a listing containing information about
    the status of the Blue Gene system in the LoadLeveler cluster.
  
    llstatus -b  

    You should receive output similar to the following:  

    Name          Base Partitions  c-nodes    InQ    Run
    BGL           1x2x4            8x16x32    4      1

11. This example generates information for base partitions R000
    and R020: 

    llstatus -B R000 R020   

    You should receive output similar to the following:  

    Base Partition Id: R000
      Base Partition State: UP
      Location: (0,0,0)
      Sub Divided Busy: False
      PartitionState=READY Partition=DD1_R000
 
    Base Partition Id: R020
      Base Partition State: UP
      Location: (0,1,0)
      Sub Divided Busy: True
      Node Card List:
        NodeCardId=J102   NodeCardState=UP   Quarter=Q1 \ 
	  PartitionState=NONE Partition=R020_J102_128
        NodeCardId=J104   NodeCardState=UP   Quarter=Q1 \
	  PartitionState=NONE Partition=R020_J102_128
        NodeCardId=J106   NodeCardState=UP   Quarter=Q1 \ 
	  PartitionState=NONE Partition=R020_J102_128
        NodeCardId=J108   NodeCardState=UP   Quarter=Q1 \ 
	  PartitionState=NONE Partition=R020_J102_128
        NodeCardId=J111   NodeCardState=UP   Quarter=Q2 \ 
	  PartitionState=NONE Partition=R020_J111_128
        NodeCardId=J113   NodeCardState=UP   Quarter=Q2 \ 
	  PartitionState=NONE Partition=R020_J111_128
        NodeCardId=J115   NodeCardState=UP   Quarter=Q2 \ 
	  PartitionState=NONE Partition=R020_J111_128
        NodeCardId=J117   NodeCardState=UP   Quarter=Q2 \ 
	  PartitionState=NONE Partition=R020_J111_128
        NodeCardId=J203   NodeCardState=UP   Quarter=Q3 \ 
	  PartitionState=NONE Partition=R020_J203_128
        NodeCardId=J205   NodeCardState=UP   Quarter=Q3 \ 
	  PartitionState=NONE Partition=R020_J203_128
        NodeCardId=J207   NodeCardState=UP   Quarter=Q3 \ 
	  PartitionState=NONE Partition=R020_J203_128
        NodeCardId=J209   NodeCardState=UP   Quarter=Q3 \ 
	  PartitionState=NONE Partition=R020_J203_128
        NodeCardId=J210   NodeCardState=UP   Quarter=Q4 \ 
	  PartitionState=NONE Partition=R020_J210_128
        NodeCardId=J212   NodeCardState=UP   Quarter=Q4 \ 
	  PartitionState=NONE Partition=R020_J210_128
        NodeCardId=J214   NodeCardState=UP   Quarter=Q4 \ 
	  PartitionState=NONE Partition=R020_J210_128
        NodeCardId=J216   NodeCardState=UP   Quarter=Q4 \ 
	  PartitionState=NONE Partition=R020_J210_128

12. This example generates information for partitions DD1_R000 and
    R020_J214_32: 

    llstatus -P DD1_R000 R020_J214_32   

    You should receive output similar to the following:   

    Partition Id: DD1_R000
      Partition State: READY
      Description: Generated via genBlock
      Owner: archerc
      Connection: TORUS
      Mode: COPROCESSOR
      MloaderImage: /bgl/BlueLight/dd1driver/bglsys/bin/mmcs-mloader.rts
      BlrtsImage: /bgl/BlueLight/dd1driver/bglsys/bin/rts_hw.rts
      LinuxImage: /bgl/BlueLight/dd1driver/bglsys/bin/zImage.elf
      RamDiskImage: /bgl/BlueLight/dd1driver/bglsys/bin/ramdisk.elf
      Small Partitions: False
      Base Partition List: R000 
      Switch ID: X_R000
        Switch State: UP
        Base Partition: R000
        Switch Dimension: X
        Switch Connections:
          FromPort=PORT_S0 ToPort=PORT_S1 PartitionState=READY \ 
	     Partition=DD1_R000
      Switch ID: Y_R000
        Switch State: UP
        Base Partition: R000
        Switch Dimension: Y
        Switch Connections:
          FromPort=PORT_S0 ToPort=PORT_S1 PartitionState=READY \ 
	     Partition=DD1_R000
      Switch ID: Z_R000
        Switch State: UP
        Base Partition: R000
        Switch Dimension: Z
        Switch Connections:
          FromPort=PORT_S0 ToPort=PORT_S1 PartitionState=READY \ 
	     Partition=DD1_R000
 
    Partition Id: R020_J214_32
      Partition State: READY
      Description: Generated via genSmallBlock
      Owner: liuycdl
      Connection: MESH
      Mode: COPROCESSOR
      MloaderImage: /bgl/BlueLight/dd1driver/bglsys/bin/mmcs-mloader.rts
      BlrtsImage: /bgl/BlueLight/dd1driver/bglsys/bin/rts_hw.rts
      LinuxImage: /bgl/BlueLight/dd1driver/bglsys/bin/zImage.elf
      RamDiskImage: /bgl/BlueLight/dd1driver/bglsys/bin/ramdisk.elf
      Small Partitions: True
      Base Partition List: R020 
      Node Card List: J214 

Security

LoadLeveler administrators and users can issue this command.
